<?php

/*
* Title                   : Pinpoint Booking System WordPress Plugin
* Version                 : 2.1.1
* File                    : includes/class-countries.php
* File Version            : 1.0
* Created / Last Modified : 02 January 2015
* Author                  : Dot on Paper
* Copyright               : © 2012 Dot on Paper
* Website                 : http://www.dotonpaper.net
* Description             : Countries PHP class.
*/

    if (!class_exists('DOPBSPCountries')){
        class DOPBSPCountries{
            /*
             * Countries list.
             */
            public $countries = array();
            
            /*
             * Constructor
             */
            function __construct(){
                add_filter('dopbsp_filter_countries', array(&$this, 'set'));
                add_action('init', array(&$this, 'init'));
            }
            
            /*
             * Initialize countries.
             */
            function init(){
                $this->countries = apply_filters('dopbsp_filter_countries', $this->countries);
            }
            
            /*
             * Get country.
             * 
             * @param code (string): country alpha 3 code
             * @param field (string): country field
             * 
             * @return country field value
             */
            function get($code = 'USA',
                         $field = 'name'){
                $field_value = 'United States';
                
                for ($i=0; $i<count($this->countries); $i++){
                    if ($this->countries[$i]['code3'] == $code){
                        $field_value = $this->currencies[$i][$field];
                        break;
                    }
                }
                
                return $field_value;
            }
            
            /*
             * Set countries.
             * 
             * @param countries (array): initial countries list 
             * 
             * @return countries array
             */
            function set($countries){
                array_push($countries, array('code2' => 'AF',
                                             'code3' => 'AFG',
                                             'name' => 'Afghanistan'));
                array_push($countries, array('code2' => 'AL',
                                             'code3' => 'ALB',
                                             'name' => 'Albania'));
                array_push($countries, array('code2' => 'DZ',
                                             'code3' => 'DZA',
                                             'name' => 'Algeria'));
                array_push($countries, array('code2' => 'AS',
                                             'code3' => 'ASM',
                                             'name' => 'American Samoa'));
                array_push($countries, array('code2' => 'AD',
                                             'code3' => 'AND',
                                             'name' => 'Andorra'));
                array_push($countries, array('code2' => 'AO',
                                             'code3' => 'AGO',
                                             'name' => 'Angola'));
                array_push($countries, array('code2' => 'AI',
                                             'code3' => 'AIA',
                                             'name' => 'Anguilla'));
                array_push($countries, array('code2' => 'AQ',
                                             'code3' => 'ATA',
                                             'name' => 'Antarctica'));
                array_push($countries, array('code2' => 'AG',
                                             'code3' => 'ATG',
                                             'name' => 'Antigua and Barbuda'));
                array_push($countries, array('code2' => 'AR',
                                             'code3' => 'ARG',
                                             'name' => 'Argentina'));
                array_push($countries, array('code2' => 'AM',
                                             'code3' => 'ARM',
                                             'name' => 'Armenia'));
                array_push($countries, array('code2' => 'AW',
                                             'code3' => 'ABW',
                                             'name' => 'Aruba'));
                array_push($countries, array('code2' => 'AU',
                                             'code3' => 'AUS',
                                             'name' => 'Australia'));
                array_push($countries, array('code2' => 'AT',
                                             'code3' => 'AUT',
                                             'name' => 'Austria'));
                array_push($countries, array('code2' => 'AZ',
                                             'code3' => 'AZE',
                                             'name' => 'Azerbaijan'));
                array_push($countries, array('code2' => 'BS',
                                             'code3' => 'BHS',
                                             'name' => 'Bahamas'));
                array_push($countries, array('code2' => 'BH',
                                             'code3' => 'BHR',
                                             'name' => 'Bahrain'));
                array_push($countries, array('code2' => 'BD',
                                             'code3' => 'BGD',
                                             'name' => 'Bangladesh'));
                array_push($countries, array('code2' => 'BB',
                                             'code3' => 'BRB',
                                             'name' => 'Barbados'));
                array_push($countries, array('code2' => 'BY',
                                             'code3' => 'BLR',
                                             'name' => 'Belarus'));
                array_push($countries, array('code2' => 'BE',
                                             'code3' => 'BEL',
                                             'name' => 'Belgium'));
                array_push($countries, array('code2' => 'BZ',
                                             'code3' => 'BLZ',
                                             'name' => 'Belize'));
                array_push($countries, array('code2' => 'BJ',
                                             'code3' => 'BEN',
                                             'name' => 'Benin'));
                array_push($countries, array('code2' => 'BM',
                                             'code3' => 'BMU',
                                             'name' => 'Bermuda'));
                array_push($countries, array('code2' => 'BT',
                                             'code3' => 'BTN',
                                             'name' => 'Bhutan'));
                array_push($countries, array('code2' => 'BO',
                                             'code3' => 'BOL',
                                             'name' => 'Bolivia'));
                array_push($countries, array('code2' => 'BA',
                                             'code3' => 'BIH',
                                             'name' => 'Bosnia and Herzegovina'));
                array_push($countries, array('code2' => 'BW',
                                             'code3' => 'BWA',
                                             'name' => 'Botswana'));
                array_push($countries, array('code2' => 'BR',
                                             'code3' => 'BRA',
                                             'name' => 'Brazil'));
                array_push($countries, array('code2' => 'IO',
                                             'code3' => 'IOT',
                                             'name' => 'British Indian Ocean Territory'));
                array_push($countries, array('code2' => 'VG',
                                             'code3' => 'VGB',
                                             'name' => 'British Virgin Islands'));
                array_push($countries, array('code2' => 'BN',
                                             'code3' => 'BRN',
                                             'name' => 'Brunei'));
                array_push($countries, array('code2' => 'BG',
                                             'code3' => 'BGR',
                                             'name' => 'Bulgaria'));
                array_push($countries, array('code2' => 'BF',
                                             'code3' => 'BFA',
                                             'name' => 'Burkina Faso'));
                array_push($countries, array('code2' => 'MM',
                                             'code3' => 'MMR',
                                             'name' => 'Burma (Myanmar)'));
                array_push($countries, array('code2' => 'BI',
                                             'code3' => 'BDI',
                                             'name' => 'Burundi'));
                array_push($countries, array('code2' => 'KH',
                                             'code3' => 'KHM',
                                             'name' => 'Cambodia'));
                array_push($countries, array('code2' => 'CM',
                                             'code3' => 'CMR',
                                             'name' => 'Cameroon'));
                array_push($countries, array('code2' => 'CA',
                                             'code3' => 'CAN',
                                             'name' => 'Canada'));
                array_push($countries, array('code2' => 'CV',
                                             'code3' => 'CPV',
                                             'name' => 'Cape Verde'));
                array_push($countries, array('code2' => 'KY',
                                             'code3' => 'CYM',
                                             'name' => 'Cayman Islands'));
                array_push($countries, array('code2' => 'CF',
                                             'code3' => 'CAF',
                                             'name' => 'Central African Republic'));
                array_push($countries, array('code2' => 'TD',
                                             'code3' => 'TCD',
                                             'name' => 'Chad'));
                array_push($countries, array('code2' => 'CL',
                                             'code3' => 'CHL',
                                             'name' => 'Chile'));
                array_push($countries, array('code2' => 'CN',
                                             'code3' => 'CHN',
                                             'name' => 'China'));
                array_push($countries, array('code2' => 'CX',
                                             'code3' => 'CXR',
                                             'name' => 'Christmas Island'));
                array_push($countries, array('code2' => 'CC',
                                             'code3' => 'CCk',
                                             'name' => 'Cocos (Keeling) Islands'));
                array_push($countries, array('code2' => 'CO',
                                             'code3' => 'COL',
                                             'name' => 'Colombia'));
                array_push($countries, array('code2' => 'KM',
                                             'code3' => 'COM',
                                             'name' => 'Comoros'));
                array_push($countries, array('code2' => 'CK',
                                             'code3' => 'COK',
                                             'name' => 'Cook Islands'));
                array_push($countries, array('code2' => 'CR',
                                             'code3' => 'CRC',
                                             'name' => 'Costa Rica'));
                array_push($countries, array('code2' => 'HR',
                                             'code3' => 'HRV',
                                             'name' => 'Croatia'));
                array_push($countries, array('code2' => 'CU',
                                             'code3' => 'CUB',
                                             'name' => 'Cuba'));
                array_push($countries, array('code2' => 'Cy',
                                             'code3' => 'Cyp',
                                             'name' => 'Cyprus'));
                array_push($countries, array('code2' => 'CZ',
                                             'code3' => 'CZE',
                                             'name' => 'Czech Republic'));
                array_push($countries, array('code2' => 'CD',
                                             'code3' => 'COD',
                                             'name' => 'Democratic Republic of the Congo'));
                array_push($countries, array('code2' => 'DK',
                                             'code3' => 'DNK',
                                             'name' => 'Denmark'));
                array_push($countries, array('code2' => 'DJ',
                                             'code3' => 'DJI',
                                             'name' => 'Djibouti'));
                array_push($countries, array('code2' => 'DM',
                                             'code3' => 'DMA',
                                             'name' => 'Dominica'));
                array_push($countries, array('code2' => 'DO',
                                             'code3' => 'DOM',
                                             'name' => 'Dominican Republic'));
                array_push($countries, array('code2' => 'EC',
                                             'code3' => 'ECU',
                                             'name' => 'Ecuador'));
                array_push($countries, array('code2' => 'EG',
                                             'code3' => 'EGY',
                                             'name' => 'Egypt'));
                array_push($countries, array('code2' => 'SV',
                                             'code3' => 'SLV',
                                             'name' => 'El Salvador'));
                array_push($countries, array('code2' => 'GQ',
                                             'code3' => 'GNQ',
                                             'name' => 'Equatorial Guinea'));
                array_push($countries, array('code2' => 'ER',
                                             'code3' => 'ERI',
                                             'name' => 'Eritrea'));
                array_push($countries, array('code2' => 'EE',
                                             'code3' => 'EST',
                                             'name' => 'Estonia'));
                array_push($countries, array('code2' => 'ET',
                                             'code3' => 'ETH',
                                             'name' => 'Ethiopia'));
                array_push($countries, array('code2' => 'FK',
                                             'code3' => 'FLK',
                                             'name' => 'Falkland Islands'));
                array_push($countries, array('code2' => 'FO',
                                             'code3' => 'FRO',
                                             'name' => 'Faroe Islands'));
                array_push($countries, array('code2' => 'FJ',
                                             'code3' => 'FJI',
                                             'name' => 'Fiji'));
                array_push($countries, array('code2' => 'FI',
                                             'code3' => 'FIN',
                                             'name' => 'Finland'));
                array_push($countries, array('code2' => 'FR',
                                             'code3' => 'FRA',
                                             'name' => 'France'));
                array_push($countries, array('code2' => 'PF',
                                             'code3' => 'PYF',
                                             'name' => 'French Polynesia'));
                array_push($countries, array('code2' => 'GA',
                                             'code3' => 'GAB',
                                             'name' => 'Gabon'));
                array_push($countries, array('code2' => 'GM',
                                             'code3' => 'GMB',
                                             'name' => 'Gambia'));
                array_push($countries, array('code2' => 'GE',
                                             'code3' => 'GEO',
                                             'name' => 'Georgia'));
                array_push($countries, array('code2' => 'DE',
                                             'code3' => 'DEU',
                                             'name' => 'Germany'));
                array_push($countries, array('code2' => 'GH',
                                             'code3' => 'GHA',
                                             'name' => 'Ghana'));
                array_push($countries, array('code2' => 'GI',
                                             'code3' => 'GIB',
                                             'name' => 'Gibraltar'));
                array_push($countries, array('code2' => 'GR',
                                             'code3' => 'GRC',
                                             'name' => 'Greece'));
                array_push($countries, array('code2' => 'GL',
                                             'code3' => 'GRL',
                                             'name' => 'Greenland'));
                array_push($countries, array('code2' => 'GD',
                                             'code3' => 'GRD',
                                             'name' => 'Grenada'));
                array_push($countries, array('code2' => 'GU',
                                             'code3' => 'GUM',
                                             'name' => 'Guam'));
                array_push($countries, array('code2' => 'GT',
                                             'code3' => 'GTM',
                                             'name' => 'Guatemala'));
                array_push($countries, array('code2' => 'GN',
                                             'code3' => 'GIN',
                                             'name' => 'Guinea'));
                array_push($countries, array('code2' => 'GW',
                                             'code3' => 'GNB',
                                             'name' => 'Guinea-Bissau'));
                array_push($countries, array('code2' => 'GY',
                                             'code3' => 'GUY',
                                             'name' => 'Guyana'));
                array_push($countries, array('code2' => 'HT',
                                             'code3' => 'HTI',
                                             'name' => 'Haiti'));
                array_push($countries, array('code2' => 'VA',
                                             'code3' => 'VAT',
                                             'name' => 'Holy See (Vatican City)'));
                array_push($countries, array('code2' => 'HN',
                                             'code3' => 'HND',
                                             'name' => 'Honduras'));
                array_push($countries, array('code2' => 'HK',
                                             'code3' => 'HKG',
                                             'name' => 'Hong Kong'));
                array_push($countries, array('code2' => 'HU',
                                             'code3' => 'HUN',
                                             'name' => 'Hungary'));
                array_push($countries, array('code2' => 'IS',
                                             'code3' => 'ISL',
                                             'name' => 'Iceland'));
                array_push($countries, array('code2' => 'IN',
                                             'code3' => 'IND',
                                             'name' => 'India'));
                array_push($countries, array('code2' => 'ID',
                                             'code3' => 'IDN',
                                             'name' => 'Indonesia'));
                array_push($countries, array('code2' => 'IR',
                                             'code3' => 'IRN',
                                             'name' => 'Iran'));
                array_push($countries, array('code2' => 'IQ',
                                             'code3' => 'IRQ',
                                             'name' => 'Iraq'));
                array_push($countries, array('code2' => 'IE',
                                             'code3' => 'IRL',
                                             'name' => 'Ireland'));
                array_push($countries, array('code2' => 'IM',
                                             'code3' => 'IMN',
                                             'name' => 'Isle of Man'));
                array_push($countries, array('code2' => 'IL',
                                             'code3' => 'ISR',
                                             'name' => 'Israel'));
                array_push($countries, array('code2' => 'IT',
                                             'code3' => 'ITA',
                                             'name' => 'Italy'));
                array_push($countries, array('code2' => 'CI',
                                             'code3' => 'CIV',
                                             'name' => 'Ivory Coast'));
                array_push($countries, array('code2' => 'JM',
                                             'code3' => 'JAM',
                                             'name' => 'Jamaica'));
                array_push($countries, array('code2' => 'JP',
                                             'code3' => 'JPN',
                                             'name' => 'Japan'));
                array_push($countries, array('code2' => 'JE',
                                             'code3' => 'JEY',
                                             'name' => 'Jersey'));
                array_push($countries, array('code2' => 'JO',
                                             'code3' => 'JOR',
                                             'name' => 'Jordan'));
                array_push($countries, array('code2' => 'KZ',
                                             'code3' => 'KAZ',
                                             'name' => 'Kazakhstan'));
                array_push($countries, array('code2' => 'KE',
                                             'code3' => 'KEN',
                                             'name' => 'Kenya'));
                array_push($countries, array('code2' => 'KI',
                                             'code3' => 'KIR',
                                             'name' => 'Kiribati'));
                array_push($countries, array('code2' => 'KW',
                                             'code3' => 'KWT',
                                             'name' => 'Kuwait'));
                array_push($countries, array('code2' => 'KG',
                                             'code3' => 'KGZ',
                                             'name' => 'Kyrgyzstan'));
                array_push($countries, array('code2' => 'LA',
                                             'code3' => 'LAO',
                                             'name' => 'Laos'));
                array_push($countries, array('code2' => 'LV',
                                             'code3' => 'LVA',
                                             'name' => 'Latvia'));
                array_push($countries, array('code2' => 'LB',
                                             'code3' => 'LBN',
                                             'name' => 'Lebanon'));
                array_push($countries, array('code2' => 'LS',
                                             'code3' => 'LSO',
                                             'name' => 'Lesotho'));
                array_push($countries, array('code2' => 'LR',
                                             'code3' => 'LBR',
                                             'name' => 'Liberia'));
                array_push($countries, array('code2' => 'LY',
                                             'code3' => 'LBY',
                                             'name' => 'Libya'));
                array_push($countries, array('code2' => 'LI',
                                             'code3' => 'LIE',
                                             'name' => 'Liechtenstein'));
                array_push($countries, array('code2' => 'LT',
                                             'code3' => 'LTU',
                                             'name' => 'Lithuania'));
                array_push($countries, array('code2' => 'LU',
                                             'code3' => 'LUX',
                                             'name' => 'Luxembourg'));
                array_push($countries, array('code2' => 'MO',
                                             'code3' => 'MAC',
                                             'name' => 'Macau'));
                array_push($countries, array('code2' => 'MK',
                                             'code3' => 'MKD',
                                             'name' => 'Macedonia'));
                array_push($countries, array('code2' => 'MG',
                                             'code3' => 'MDG',
                                             'name' => 'Madagascar'));
                array_push($countries, array('code2' => 'MW',
                                             'code3' => 'MWI',
                                             'name' => 'Malawi'));
                array_push($countries, array('code2' => 'MY',
                                             'code3' => 'MYS',
                                             'name' => 'Malaysia'));
                array_push($countries, array('code2' => 'MV',
                                             'code3' => 'MDV',
                                             'name' => 'Maldives'));
                array_push($countries, array('code2' => 'ML',
                                             'code3' => 'MLI',
                                             'name' => 'Mali'));
                array_push($countries, array('code2' => 'MT',
                                             'code3' => 'MLT',
                                             'name' => 'Malta'));
                array_push($countries, array('code2' => 'MH',
                                             'code3' => 'MHL',
                                             'name' => 'Marshall Islands'));
                array_push($countries, array('code2' => 'MR',
                                             'code3' => 'MRT',
                                             'name' => 'Mauritania'));
                array_push($countries, array('code2' => 'MU',
                                             'code3' => 'MUS',
                                             'name' => 'Mauritius'));
                array_push($countries, array('code2' => 'YT',
                                             'code3' => 'MYT',
                                             'name' => 'Mayotte'));
                array_push($countries, array('code2' => 'MX',
                                             'code3' => 'MEX',
                                             'name' => 'Mexico'));
                array_push($countries, array('code2' => 'FM',
                                             'code3' => 'FSM',
                                             'name' => 'Micronesia'));
                array_push($countries, array('code2' => 'MD',
                                             'code3' => 'MDA',
                                             'name' => 'Moldova'));
                array_push($countries, array('code2' => 'MC',
                                             'code3' => 'MCO',
                                             'name' => 'Monaco'));
                array_push($countries, array('code2' => 'MN',
                                             'code3' => 'MNG',
                                             'name' => 'Mongolia'));
                array_push($countries, array('code2' => 'ME',
                                             'code3' => 'MNE',
                                             'name' => 'Montenegro'));
                array_push($countries, array('code2' => 'MS',
                                             'code3' => 'MSR',
                                             'name' => 'Montserrat'));
                array_push($countries, array('code2' => 'MA',
                                             'code3' => 'MAR',
                                             'name' => 'Morocco'));
                array_push($countries, array('code2' => 'MZ',
                                             'code3' => 'MOZ',
                                             'name' => 'Mozambique'));
                array_push($countries, array('code2' => 'NA',
                                             'code3' => 'NAM',
                                             'name' => 'Namibia'));
                array_push($countries, array('code2' => 'NR',
                                             'code3' => 'NRU',
                                             'name' => 'Nauru'));
                array_push($countries, array('code2' => 'NP',
                                             'code3' => 'NPL',
                                             'name' => 'Nepal'));
                array_push($countries, array('code2' => 'NL',
                                             'code3' => 'NLD',
                                             'name' => 'Netherlands'));
                array_push($countries, array('code2' => 'AN',
                                             'code3' => 'ANT',
                                             'name' => 'Netherlands Antilles'));
                array_push($countries, array('code2' => 'NC',
                                             'code3' => 'NCL',
                                             'name' => 'New Caledonia'));
                array_push($countries, array('code2' => 'NZ',
                                             'code3' => 'NZL',
                                             'name' => 'New Zealand'));
                array_push($countries, array('code2' => 'NI',
                                             'code3' => 'NIC',
                                             'name' => 'Nicaragua'));
                array_push($countries, array('code2' => 'NE',
                                             'code3' => 'NER',
                                             'name' => 'Niger'));
                array_push($countries, array('code2' => '',
                                             'code3' => '',
                                             'name' => 'Nigeria'));
                array_push($countries, array('code2' => '',
                                             'code3' => '',
                                             'name' => 'Niue'));
                array_push($countries, array('code2' => 'NF',
                                             'code3' => 'NFK',
                                             'name' => 'Norfolk Island'));
                array_push($countries, array('code2' => 'KP',
                                             'code3' => 'PRK',
                                             'name' => 'North Korea'));
                array_push($countries, array('code2' => 'MP',
                                             'code3' => 'MNP',
                                             'name' => 'Northern Mariana Islands'));
                array_push($countries, array('code2' => 'NO',
                                             'code3' => 'NOR',
                                             'name' => 'Norway'));
                array_push($countries, array('code2' => 'OM',
                                             'code3' => 'OMN',
                                             'name' => 'Oman'));
                array_push($countries, array('code2' => 'PK',
                                             'code3' => 'PAK',
                                             'name' => 'Pakistan'));
                array_push($countries, array('code2' => 'PW',
                                             'code3' => 'PLW',
                                             'name' => 'Palau'));
                array_push($countries, array('code2' => 'PA',
                                             'code3' => 'PAN',
                                             'name' => 'Panama'));
                array_push($countries, array('code2' => 'PG',
                                             'code3' => 'PNG',
                                             'name' => 'Papua New Guinea'));
                array_push($countries, array('code2' => 'PY',
                                             'code3' => 'PRY',
                                             'name' => 'Paraguay'));
                array_push($countries, array('code2' => 'PE',
                                             'code3' => 'PER',
                                             'name' => 'Peru'));
                array_push($countries, array('code2' => 'PH',
                                             'code3' => 'PHL',
                                             'name' => 'Philippines'));
                array_push($countries, array('code2' => 'PN',
                                             'code3' => 'PCN',
                                             'name' => 'Pitcairn Islands'));
                array_push($countries, array('code2' => 'PL',
                                             'code3' => 'POL',
                                             'name' => 'Poland'));
                array_push($countries, array('code2' => 'PT',
                                             'code3' => 'PRT',
                                             'name' => 'Portugal'));
                array_push($countries, array('code2' => 'PR',
                                             'code3' => 'PRI',
                                             'name' => 'Puerto Rico'));
                array_push($countries, array('code2' => 'QA',
                                             'code3' => 'QAT',
                                             'name' => 'Qatar'));
                array_push($countries, array('code2' => 'CG',
                                             'code3' => 'COG',
                                             'name' => 'Republic of the Congo'));
                array_push($countries, array('code2' => 'RO',
                                             'code3' => 'ROU',
                                             'name' => 'Romania'));
                array_push($countries, array('code2' => 'RU',
                                             'code3' => 'RUS',
                                             'name' => 'Russia'));
                array_push($countries, array('code2' => 'RW',
                                             'code3' => 'RWA',
                                             'name' => 'Rwanda'));
                array_push($countries, array('code2' => 'BL',
                                             'code3' => 'BLM',
                                             'name' => 'Saint Barthelemy'));
                array_push($countries, array('code2' => 'SH',
                                             'code3' => 'SHN',
                                             'name' => 'Saint Helena'));
                array_push($countries, array('code2' => 'KN',
                                             'code3' => 'KNA',
                                             'name' => 'Saint Kitts and Nevis'));
                array_push($countries, array('code2' => 'LC',
                                             'code3' => 'LCA',
                                             'name' => 'Saint Lucia'));
                array_push($countries, array('code2' => 'MF',
                                             'code3' => 'MAF',
                                             'name' => 'Saint Martin'));
                array_push($countries, array('code2' => 'PM',
                                             'code3' => 'SPM',
                                             'name' => 'Saint Pierre and Miquelon'));
                array_push($countries, array('code2' => 'VC',
                                             'code3' => 'VCT',
                                             'name' => 'Saint Vincent and the Grenadines'));
                array_push($countries, array('code2' => 'WS',
                                             'code3' => 'WSM',
                                             'name' => 'Samoa'));
                array_push($countries, array('code2' => 'SM',
                                             'code3' => 'SMR',
                                             'name' => 'San Marino'));
                array_push($countries, array('code2' => 'ST',
                                             'code3' => 'STP',
                                             'name' => 'Sao Tome and Principe'));
                array_push($countries, array('code2' => 'SA',
                                             'code3' => 'SAU',
                                             'name' => 'Saudi Arabia'));
                array_push($countries, array('code2' => 'SN',
                                             'code3' => 'SEN',
                                             'name' => 'Senegal'));
                array_push($countries, array('code2' => 'RS',
                                             'code3' => 'SRB',
                                             'name' => 'Serbia'));
                array_push($countries, array('code2' => 'SC',
                                             'code3' => 'SYC',
                                             'name' => 'Seychelles'));
                array_push($countries, array('code2' => 'SL',
                                             'code3' => 'SLE',
                                             'name' => 'Singapore'));
                array_push($countries, array('code2' => 'SG',
                                             'code3' => 'SGP',
                                             'name' => 'Singapore'));
                array_push($countries, array('code2' => 'SK',
                                             'code3' => 'SVK',
                                             'name' => 'Slovakia'));
                array_push($countries, array('code2' => 'SI',
                                             'code3' => 'SVN',
                                             'name' => 'Slovenia'));
                array_push($countries, array('code2' => 'SB',
                                             'code3' => 'SLB',
                                             'name' => 'Solomon Islands'));
                array_push($countries, array('code2' => 'SO',
                                             'code3' => 'SOM',
                                             'name' => 'Somalia'));
                array_push($countries, array('code2' => 'ZA',
                                             'code3' => 'ZAF',
                                             'name' => 'South Africa'));
                array_push($countries, array('code2' => 'KR',
                                             'code3' => 'KOR',
                                             'name' => 'South Korea'));
                array_push($countries, array('code2' => 'ES',
                                             'code3' => 'ESP',
                                             'name' => 'Spain'));
                array_push($countries, array('code2' => 'LK',
                                             'code3' => 'LKA',
                                             'name' => 'Sri Lanka'));
                array_push($countries, array('code2' => 'SD',
                                             'code3' => 'SDN',
                                             'name' => 'Sudan'));
                array_push($countries, array('code2' => 'SR',
                                             'code3' => 'SUR',
                                             'name' => 'Suriname'));
                array_push($countries, array('code2' => 'SJ',
                                             'code3' => 'SJM',
                                             'name' => 'Svalbard'));
                array_push($countries, array('code2' => 'SZ',
                                             'code3' => 'SWZ',
                                             'name' => 'Swaziland'));
                array_push($countries, array('code2' => 'SE',
                                             'code3' => 'SWE',
                                             'name' => 'Sweden'));
                array_push($countries, array('code2' => 'CH',
                                             'code3' => 'CHE',
                                             'name' => 'Switzerland'));
                array_push($countries, array('code2' => 'SY',
                                             'code3' => 'SYR',
                                             'name' => 'Syria'));
                array_push($countries, array('code2' => 'TW',
                                             'code3' => 'TWN',
                                             'name' => 'Taiwan'));
                array_push($countries, array('code2' => 'TJ',
                                             'code3' => 'TJK',
                                             'name' => 'Tajikistan'));
                array_push($countries, array('code2' => 'TZ',
                                             'code3' => 'TZA',
                                             'name' => 'Tanzania'));
                array_push($countries, array('code2' => 'TH',
                                             'code3' => 'THA',
                                             'name' => 'Thailand'));
                array_push($countries, array('code2' => 'TL',
                                             'code3' => 'TLS',
                                             'name' => 'Timor-Leste'));
                array_push($countries, array('code2' => 'TG',
                                             'code3' => 'TGO',
                                             'name' => 'Togo'));
                array_push($countries, array('code2' => 'TK',
                                             'code3' => 'TKL',
                                             'name' => 'Tokelau'));
                array_push($countries, array('code2' => 'TO',
                                             'code3' => 'TON',
                                             'name' => 'Tonga'));
                array_push($countries, array('code2' => 'TT',
                                             'code3' => 'TTO',
                                             'name' => 'Trinidad and Tobago'));
                array_push($countries, array('code2' => 'TN',
                                             'code3' => 'TUN',
                                             'name' => 'Tunisia'));
                array_push($countries, array('code2' => 'TR',
                                             'code3' => 'TUR',
                                             'name' => 'Turkey'));
                array_push($countries, array('code2' => 'TM',
                                             'code3' => 'TKM',
                                             'name' => 'Turkmenistan'));
                array_push($countries, array('code2' => 'TC',
                                             'code3' => 'TCA',
                                             'name' => 'Turks and Caicos Islands'));
                array_push($countries, array('code2' => 'TV',
                                             'code3' => 'TUV',
                                             'name' => 'Tuvalu'));
                array_push($countries, array('code2' => 'UG',
                                             'code3' => 'UGA',
                                             'name' => 'Uganda'));
                array_push($countries, array('code2' => 'UA',
                                             'code3' => 'UKR',
                                             'name' => 'Ukraine'));
                array_push($countries, array('code2' => 'AE',
                                             'code3' => 'ARE',
                                             'name' => 'United Arab Emirates'));
                array_push($countries, array('code2' => 'GB',
                                             'code3' => 'GBR',
                                             'name' => 'United Kingdom'));
                array_push($countries, array('code2' => 'US',
                                             'code3' => 'USA',
                                             'name' => 'United States'));
                array_push($countries, array('code2' => 'UY',
                                             'code3' => 'URY',
                                             'name' => 'Uruguay'));
                array_push($countries, array('code2' => 'VI',
                                             'code3' => 'VIR',
                                             'name' => 'US Virgin Islands'));
                array_push($countries, array('code2' => 'UZ',
                                             'code3' => 'UZB',
                                             'name' => 'Uzbekistan'));
                array_push($countries, array('code2' => 'VU',
                                             'code3' => 'VUT',
                                             'name' => 'Vanuatu'));
                array_push($countries, array('code2' => 'VE',
                                             'code3' => 'VEN',
                                             'name' => 'Venezuela'));
                array_push($countries, array('code2' => 'VN',
                                             'code3' => 'VNM',
                                             'name' => 'Vietnam'));
                array_push($countries, array('code2' => 'WF',
                                             'code3' => 'WLF',
                                             'name' => 'Wallis and Futuna'));
                array_push($countries, array('code2' => 'EH',
                                             'code3' => 'ESH',
                                             'name' => 'Western Sahara'));
                array_push($countries, array('code2' => 'YE',
                                             'code3' => 'YEM',
                                             'name' => 'Yemen'));
                array_push($countries, array('code2' => 'ZM',
                                             'code3' => 'ZMB',
                                             'name' => 'Zambia'));
                array_push($countries, array('code2' => 'ZW',
                                             'code3' => 'ZWE',
                                             'name' => 'Zimbabwe'));
                
                return $countries;
            }
        }
    }